@@ -1,6 +1,6 @@
 package JBD::Javascript;
 # ABSTRACT: provides Javascript parsing subs
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 # Javascript parsing subs.
 # @author Joel Dalley
@@ -10,20 +10,12 @@ use JBD::Core::Exporter ':omni';
 
 use JBD::Parser::DSL;
 use JBD::Javascript::Lexers;
-use JBD::Javascript::Grammar;
-use JBD::Javascript::Transformers 'remove_novalue';
 
 # @param string $parser A JBD::Parser sub name.
 # @param scalar/ref $text Javascript text.
 # @return arrayref Array of JBD::Parser::Tokens.
 sub std_parse(@) {
     my ($parser, $text) = @_;
-
-    init;
-    my $st = parser_state tokens $text, [];
-
-    no strict 'refs';
-    remove_novalue &$parser->($st) or die $st->error_string;
 }
 
 1;
@@ -40,7 +32,7 @@ JBD::Javascript - provides Javascript parsing subs
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 AUTHOR
 
